%define major           2
%define libname         %mklibname %{name} %{major}
%define develname       %mklibname %{name} -d
%global _hardened_build 1
%global skiptests       1

Name:          zookeeper
Version:       3.4.9
Release:       %mkrel 2
Summary:       A high-performance coordination service for distributed applications
Group:         Development/Java
License:       ASL 2.0 and BSD
URL:           https://zookeeper.apache.org/
Source0:       https://www.apache.org/dist/%{name}/%{name}-%{version}.tar.gz
Source1:       %{name}-ZooInspector-template.pom
Source2:       %{name}.service
Source3:       zkEnv.sh

Patch1:        %{name}-3.4.5-zktreeutil-gcc.patch
Patch2:        %{name}-3.4.9-ivy-build.patch
Patch3:        %{name}-3.4.9-server.patch
# ZOOKEEPER-1643; patch accepted in 3.5.0
Patch4:        mt_adaptor.c.patch
Patch5:        0001-cppunit-config-no-longer-exists-use-pkg-config.patch
Patch6:        missing-pom.template.patch
# Debian patches:
Patch100:      zookeeper-3.4.9-CVE-2017-5637.patch

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: boost-devel
BuildRequires: cppunit-devel
BuildRequires: dos2unix
BuildRequires: doxygen
BuildRequires: graphviz
BuildRequires: java-devel
BuildRequires: java-javadoc
BuildRequires: jpackage-utils
BuildRequires: libtool
BuildRequires: libxml2-devel
BuildRequires: log4cxx-devel
BuildRequires: python-devel

BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: apache-ivy
BuildRequires: checkstyle
BuildRequires: ivy-local
BuildRequires: javapackages-tools

BuildRequires: jtoaster
BuildRequires: junit
BuildRequires: jdiff
BuildRequires: liblog4j12-java
BuildRequires: mvn(org.slf4j:slf4j-log4j12)
BuildRequires: objectweb-pom
BuildRequires: jline1
BuildRequires: netty3

BuildRequires: json_simple

BuildRequires: mockito
BuildRequires: slf4j
BuildRequires: xerces-j2
BuildRequires: xml-commons-apis

# remove later on.
BuildRequires: apache-commons-parent
BuildRequires: jetty-server
BuildRequires: jetty-servlet
BuildRequires: systemd

%description
ZooKeeper is a centralized service for maintaining configuration information,
naming, providing distributed synchronization, and providing group services.

%package -n    %{libname}
Summary:       Zookeeper C client library
Group:         System/Libraries

%description -n %{libname}
ZooKeeper C client library for communicating with ZooKeeper Server.

%package -n    %{develname}
Summary:       Development files for the %{name} library
Group:         Development/C++
Requires:      %{libname} = %{version}-%{release}
Provides:      %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the ZooKeeper C client library.

%package       lib-doc
Summary:       Documentation for the %{name} library
Group:         Documentation
BuildArch:     noarch

%description   lib-doc
Documentation for the ZooKeeper C client library.

%package       java
Summary:       Zookeeper Java client library
Group:         Development/Java
BuildArch:     noarch
Requires:      checkstyle
Requires:      jline1
Requires:      jtoaster
Requires:      junit
Requires:      log4j12
Requires:      liblog4j12-java
Requires:      mockito
Requires:      netty3
Requires:      slf4j
Requires:      java
Requires:      jpackage-utils

%description   java
This package provides a Java client interface to Zookeeper server.

%package       javadoc
Summary:       Javadoc for %{name}
Group:         Documentation
BuildArch:     noarch

%description   javadoc
This package contains javadoc for %{name}.

%package -n    python-%{name}
Summary:       ZooKeeper python binding library
Group:         Development/Python
Requires:      %{libname} = %{version}-%{release}
Provides:      zkpython = %{version}-%{release}
Obsoletes:     python-ZooKeeper < 3.4.5-26
Provides:      python-ZooKeeper = %{version}-%{release}

%description -n python-%{name}
ZooKeeper python binding library.

%package       server
Summary:       ZooKeeper server
Group:         System/Servers
Requires:      %{name}-java = %{version}-%{release}
BuildArch:     noarch
Requires(post):   systemd
Requires(post):   rpm-helper
Requires(preun):  systemd
Requires(preun):  rpm-helper
Requires(postun): systemd
Requires(pre):    shadow-utils

%description   server
ZooKeeper server.

%prep
%autosetup -p1

iconv -f iso8859-1 -t utf-8 src/c/ChangeLog > src/c/ChangeLog.conv && mv -f src/c/ChangeLog.conv src/c/ChangeLog
sed -i 's/\r//' src/c/ChangeLog

sed -i 's|<exec executable="hostname" outputproperty="host.name"/>|<!--exec executable="hostname" outputproperty="host.name"/-->|' build.xml
sed -i 's|<attribute name="Built-On" value="${host.name}" />|<attribute name="Built-On" value="${user.name}" />|' build.xml

sed -i 's@^dataDir=.*$@dataDir=%{_sharedstatedir}/zookeeper/data\ndataLogDir=%{_sharedstatedir}/zookeeper/log@' conf/zoo_sample.cfg

%build
%ant -Divy.mode=local \
-DCLASSPATH=/usr/lib/java/log4j12-1.2.17.jar \
-Dtarget.jdk=1.5 \
-Djavadoc.link.java=%{_javadocdir}/java \
-Dant.build.javac.source=1.5 \
-Dant.build.javac.target=1.5 \
package

pushd src/c
autoreconf -vif
%configure2_5x --disable-static --disable-rpath
%make_build
%make_build doxygen-doc
popd

# Compile zktreeutil
pushd src/contrib/zktreeutil
autoreconf -vfi
%configure2_5x
%make_build
popd

## TODO: install utilities?

%check
%if %skiptests
  echo "Testing disabled, please enable in mock"
%else
  %ant -Divy.mode=local test
%endif

%install

# the following is used to update zkEnv.sh
# find . -name "*.jar" -exec basename {} \; |sort|uniq
# remove items that don't belong and update execute build-classpath

#install the c tools
pushd src/c
%make_install
popd

#install the zktreeutil tools
pushd src/contrib/zktreeutil
%make_install
popd

# install the java dependencies.
mkdir -p %{buildroot}%{_javadir}/%{name}
install -pm 644 build/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
install -pm 644 build/%{name}-%{version}-test.jar %{buildroot}%{_javadir}/%{name}/%{name}-tests.jar
install -pm 644 build/contrib/ZooInspector/%{name}-%{version}-ZooInspector.jar %{buildroot}%{_javadir}/%{name}/%{name}-ZooInspector.jar

install -pm 755 bin/zkCleanup.sh %{buildroot}%{_bindir}
install -pm 755 bin/zkCli.sh %{buildroot}%{_bindir}
install -pm 755 bin/zkServer.sh %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libexecdir}
install -pm 755 %{SOURCE3} %{buildroot}%{_libexecdir}

mkdir -p %{buildroot}%{_datadir}/maven-metadata
mkdir -p %{buildroot}%{_datadir}/maven-poms
install -pm 644 build/%{name}-%{version}/dist-maven/%{name}-%{version}.pom %{buildroot}%{_datadir}/maven-poms/%{name}-%{name}.pom

%add_maven_depmap %{name}-%{name}.pom %{name}/%{name}.jar
%add_maven_depmap org.apache.zookeeper:zookeeper::tests:%{version} %{name}/%{name}-tests.jar

install -pm 644 %{SOURCE1} %{buildroot}%{_datadir}/maven-poms/%{name}-%{name}-ZooInspector.pom
sed -i "s|@version@|%{version}|" %{buildroot}%{_datadir}/maven-poms/%{name}-%{name}-ZooInspector.pom
%add_maven_depmap %{name}-%{name}-ZooInspector.pom %{name}/%{name}-ZooInspector.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr build/docs/api/* %{buildroot}%{_javadocdir}/%{name}/

#install the zkpython tools
pushd src/contrib/zkpython
%{__python} src/python/setup.py build --build-base=$PWD/build \
install --root=%{buildroot} ;\
chmod 0755 %{buildroot}%{python_sitearch}/zookeeper.so
popd

find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/zookeeper
mkdir -p %{buildroot}%{_localstatedir}/log/zookeeper
mkdir -p %{buildroot}%{_sharedstatedir}/zookeeper
mkdir -p %{buildroot}%{_sharedstatedir}/zookeeper/data
mkdir -p %{buildroot}%{_sharedstatedir}/zookeeper/log
install -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}
install -p -m 0640 conf/log4j.properties %{buildroot}%{_sysconfdir}/zookeeper
install -p -m 0640 conf/zoo_sample.cfg %{buildroot}%{_sysconfdir}/zookeeper
touch %{buildroot}%{_sysconfdir}/zookeeper/zoo.cfg
touch %{buildroot}%{_sharedstatedir}/zookeeper/data/myid

%pre server
%_pre_useradd %{name} %{_sharedstatedir}/%{name} /sbin/nologin

%postun server
%_postun_userdel %{name}

%post server
%_tmpfilescreate %{name}
%_post_service %{name}

%preun server
%_preun_service %{name}

%files
%{_bindir}/cli_mt
%{_bindir}/cli_st
%{_bindir}/load_gen
%{_bindir}/zktreeutil
%{_bindir}/zk*.sh
%{_libexecdir}/zkEnv.sh
%doc src/c/ChangeLog src/c/LICENSE src/c/NOTICE.txt src/c/README src/contrib/zktreeutil/README.txt

%files -n %{libname}
%{_libdir}/lib*.so.*
%doc src/c/LICENSE src/c/NOTICE.txt

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/*.so
%doc src/c/LICENSE src/c/NOTICE.txt

%files lib-doc
%doc src/c/LICENSE src/c/NOTICE.txt src/c/docs/html/*

%files java -f .mfiles
%dir %{_javadir}/%{name}
%doc CHANGES.txt LICENSE.txt NOTICE.txt README.txt

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE.txt NOTICE.txt

%files -n python-%{name}
%{python2_sitearch}/ZooKeeper-?.?-py%{python2_version}.egg-info
%{python2_sitearch}/zookeeper.so
%doc LICENSE.txt NOTICE.txt src/contrib/zkpython/README

%files server
%attr(0755,root,root) %dir %{_sysconfdir}/zookeeper
%attr(0644,root,root) %ghost %config(noreplace) %{_sysconfdir}/zookeeper/zoo.cfg
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/zookeeper/zoo_sample.cfg
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/zookeeper/log4j.properties

%attr(0750,zookeeper,zookeeper) %dir %{_localstatedir}/log/zookeeper
%attr(0755,root,root) %dir %{_sharedstatedir}/zookeeper
%attr(0750,zookeeper,zookeeper) %dir %{_sharedstatedir}/zookeeper/data
%attr(0640,zookeeper,zookeeper) %ghost %{_sharedstatedir}/zookeeper/data/myid
%attr(0750,zookeeper,zookeeper) %dir %{_sharedstatedir}/zookeeper/log
%{_unitdir}/zookeeper.service
%doc CHANGES.txt LICENSE.txt NOTICE.txt README.txt


%changelog
* Fri Jun 02 2017 daviddavid <daviddavid> 3.4.9-2.mga6
+ Revision: 1105831
- add debian patch to fix CVE-2017-5637 (mga#21014)

* Sun Jan 01 2017 daviddavid <daviddavid> 3.4.9-1.mga6
+ Revision: 1079263
- new version: 3.4.9 (fixes CVE-2016-5017, sync with Fedora)
- remove merged upstream CVE-2016-5017 patch

* Tue Sep 20 2016 daviddavid <daviddavid> 3.4.6-5.mga6
+ Revision: 1054539
- add patch from debian to fix CVE-2016-5017 (mga#19419)

* Sat Feb 27 2016 daviddavid <daviddavid> 3.4.6-4.mga6
+ Revision: 980198
- sync zookeeper package with fedora 24
  * Remove duplicates and fix broken classpath items in zkEnv
  * Fix bz#1272694 Remove precondition on myid file for standalone defaults
  * Update zkEnv.sh CLASSPATH to fix bz#1261458
  * Update netty3 patch for 3.9.3
- use new python macros
- rebuild against current java stack

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Dec 06 2015 neoclust <neoclust> 3.4.6-3.mga6
+ Revision: 908553
- Rebuild for ARM

* Fri Sep 25 2015 daviddavid <daviddavid> 3.4.6-2.mga6
+ Revision: 883457
- rebuild for new boost 1.59.0

* Sat Jul 11 2015 daviddavid <daviddavid> 3.4.6-1.mga6
+ Revision: 853277
- new version: 3.4.6 (based on fc23)
- remove unneeded patches
- update BuildRequires and Requires
- rename subpackage python on python-zookeeper (instead of python-ZooKeeper)
- update zookeeper.service file
- update file list

* Fri Jan 02 2015 daviddavid <daviddavid> 3.4.5-25.mga5
+ Revision: 808204
- switch to log4j12 (log4j-1.2.17)
- add patch to fix the path of log4j-1.2.17.jar
  * zookeeper-3.4.5-mga-find_liblog4j12_path.patch
- update BuildRequires and Requires
- add missing BuildRequires on slf4j-log4j12 (fix build failure)
- use .mfiles generated during build (fix build failure)
- use appropriate post/pre/postun/preun macros for mageia
- use %%makeinstall_std and %%configure2_5x macros for mageia
- fix Group
- fix provides on python-ZooKeeper package
- add missing Requires on rpm-helper
- fix a non-conffile-in-etc for zoo_sample.cfg file
- add doc on -server subpackage

* Wed Oct 15 2014 umeabot <umeabot> 3.4.5-24.mga5
+ Revision: 743568
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.4.5-23.mga5
+ Revision: 730759
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.4.5-22.mga5
+ Revision: 690887
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Tue May 20 2014 fwang <fwang> 3.4.5-20.mga5
+ Revision: 624468
- add provides

* Tue May 20 2014 fwang <fwang> 3.4.5-19.mga5
+ Revision: 624154
- fix requires

* Mon May 19 2014 dmorgan <dmorgan> 3.4.5-18.mga5
+ Revision: 623964
- Rebuild against fixed java stack
- Add java support

* Thu Jan 09 2014 spuhler <spuhler> 3.4.5-1.mga4
+ Revision: 565939
- upgrade to version 3.4.5

* Mon Feb 07 2011 spuhler <spuhler> 3.2.1-1.mga1
+ Revision: 48375
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package zookeeper


* Sat Oct 17 2009 Oden Eriksson <oeriksson@mandriva.com> 3.2.1-1mdv2010.0
+ Revision: 458005
- import zookeeper


* Sat Oct 17 2009 Oden Eriksson <oeriksson@mandriva.com> 3.2.1-1mdv2009.1
- 3.2.1
- the package was renamed to just zookeeper (someone should package the java bits...)

* Sat May 03 2008 Oden Eriksson <oeriksson@mandriva.com> 2.1.0-1mdv2009.0
+ Revision: 200092
- import zookeeper-c

* Sat May 03 2008 Oden Eriksson <oeriksson@mandriva.com> 2.1.0-1mdv2009.0
- initial Mandriva package
